==> hs-webkit-0.12.4_1.tbz: lib/ghc-7.4.1/cabal/webkit-0.12.4/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.4
id: webkit-0.12.4-57be8b46134f89bb75cd35b374f162b0

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Webkit library.
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/webkit-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/webkit-0.12.4
              /usr/local/lib
hs-libraries: HSwebkit-0.12.4
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 gdk-x11-2.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage Xfixes X11 atk-1.0 cairo gdk_pixbuf-2.0 pangoft2-1.0
                 pango-1.0 m freetype fontconfig soup-2.4 gio-2.0 gobject-2.0
                 gthread-2.0 gmodule-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/webkit-1.0
              /usr/local/include/gtk-2.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/pixman-1 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/libpng15 /usr/local/include/pango-1.0
              /usr/local/include/freetype2 /usr/local/include/libsoup-2.4
              /usr/local/include/glib-2.0 /usr/local/include/libxml2
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         cairo-0.12.3.1-f7a457a5a758d563889e8e3c4b5c748c
         glib-0.12.3.1-85cbbfa847e6d4009f64bf9e4957ee21
         gtk-0.12.3.1-bb799f6cbfc601b58d749d33476c453d
         pango-0.12.3-152fed3efbb178d07db4a01583547179
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/webkit-0.12.4/html/webkit.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/webkit-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-webkit-0.12.4_3.tbz: lib/ghc-7.4.2/cabal/webkit-0.12.4/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.4
id: webkit-0.12.4-ee9b46d13f1137b878f24282a2ec3f58

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Webkit library.
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/webkit-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/webkit-0.12.4
              /usr/local/lib
hs-libraries: HSwebkit-0.12.4
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 gdk-x11-2.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage Xfixes X11 atk-1.0 cairo gdk_pixbuf-2.0 pangoft2-1.0
                 pango-1.0 freetype fontconfig soup-2.4 gio-2.0 gobject-2.0
                 javascriptcoregtk-1.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gtk-2.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/atk-1.0
              /usr/local/include/cairo /usr/local/include/pixman-1
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng15
              /usr/local/include/pango-1.0 /usr/local/include/freetype2
              /usr/local/include/libsoup-2.4 /usr/local/include/libxml2
              /usr/local/include/webkitgtk-1.0 /usr/local/include/glib-2.0
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         cairo-0.12.4-2d47e71a1445815024ecedde0f6622ab
         glib-0.12.4-2696509aa1c1a77771da26d8647d44d8
         gtk-0.12.4-19f6ea5cde84c1b0aa851a75dc1f4905
         pango-0.12.4-cdcefbd659cbfc396359822d86eab665
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/webkit-0.12.4/html/webkit.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/webkit-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
